#!/usr/bin/env python
# -*- coding: utf-8 -*-

# 2015-05-06 David Goncalves <david@lestat.st>
#            MessageEncoder is a script that uses the RFAudioCoder class to encode
#            messages to be sent via audio device or to a WAV file.

import argparse
import RFAudioCoder

if __name__ == "__main__" : 

    options = argparse.ArgumentParser()
    options.add_argument( "--debug", dest="debug", action="store_true", default=False, help="Print debug messages" )
    options.add_argument( "--protocol", dest="proto", required=True, choices=RFAudioCoder.RFAudioCoder.protocols.keys(), help="Protocol used for encoding" )
    options.add_argument( "--message", dest="message", required=True, type=int, help="Message to be encoded (numeric)" )
    options.add_argument( "--encode-dest", dest="dest", choices=['audio','wav'], default='audio', help="Encode message to audio or to a wav (default: audio)" )
    options.add_argument( "--wav-file", dest="wav", help="Path for the generated wav file" )
    options.add_argument( "--override-freq", dest="freq", type=int, default=8000, help="Override audio frequency (default: 8000Hz)" )
    options.add_argument( "--override-bits", dest="bits", type=int, default=24, help="Override protocol bits (default: 24)" )
    options.add_argument( "--override-repeat", dest="repeat", type=int, default=8, help="Override message repeat (default: 8)" )

    args = options.parse_args()

    if ( ( args.dest == "wav" ) and ( args.wav == None ) ) :
        raise ValueError( "You must provide 'wav-file' argument when exporting to wav" )

    coder = RFAudioCoder.RFAudioCoder( debug=args.debug )
    coder.SetAudioFrequency( args.freq )
    coder.SetMessageBitLength( args.bits )
    coder.SetMessageRepeat( args.repeat )

    if ( args.dest == "audio" ) :
        coder.ExportAudio( args.proto, args.message )

    if ( args.dest == "wav" ) :
        coder.ExportWAV( args.proto, args.message, args.wav )

